@@ -9,9 +9,9 @@ from exchangelib import Message, FileAttachment, ItemAttachment
 
 
 # Read & Save Attachments code
-def save_attachment(exchange_folder_name: str, save_to_folder: str, exchangelib_account, suffix=0,
+def save_attachment(exchange_folder_name: str, save_to_folder: str, account_var, suffix=0,
                     prename='', last_items=1) -> str:
-    folder = exchangelib_account.account.inbox / exchange_folder_name
+    folder = account_var.inbox / exchange_folder_name
     for item in folder.all().order_by('-datetime_received')[:last_items]:
         for attachment in item.attachments:
             print('Number of Attachment found:', len(item.attachments))
