@@ -5,14 +5,15 @@ Created on 20.04.2021
 """
 
 import os
+from dotenv import load_dotenv
 import pandas as pd
-
 from accessOutlookEmail import save_attachment, create_account
 
-account = create_account('kreutmair@orcacapital.de', 'jar54Cet$cosh45')
+load_dotenv()
 
 
-def editSaveMorrison(rename_file: str, load_from_folder: str, save_to_folder: str):
+def edit_save_morrison(rename_file: str, load_from_folder: str, save_to_folder: str):
+    account = create_account(os.getenv('email_robert'), os.getenv('password_robert'))
     # open Excel
     os.chdir(load_from_folder)
     df = pd.read_excel(save_attachment('Morrison', load_from_folder, account))
@@ -37,7 +38,7 @@ def editSaveMorrison(rename_file: str, load_from_folder: str, save_to_folder: st
 
 
 def main():
-    editSaveMorrison(r'testFile.xlsx', r'C:\Users\baier\Downloads', r'O:\Listenpflege\AU_Leihe_Option')
+    edit_save_morrison(r'testFile.xlsx', r'C:\Users\baier\Downloads', r'O:\Listenpflege\AU_Leihe_Option')
 
 
 if __name__ == '__main__':
