@@ -5,12 +5,13 @@ Created on 20.04.2021
 """
 import pandas as pd
 import os
+from dotenv import load_dotenv
 from accessOutlookEmail import create_account, send_email, save_attachment
 
-account = create_account('kreutmair@orcacapital.de', 'jar54Cet$cosh45')
+load_dotenv()
 
 
-def editSaveReport(save_to_folder: str):
+def edit_save_report(save_to_folder: str, account):
     # open Excel
     os.chdir(save_to_folder)
     df = pd.read_excel(save_attachment('JoinITReport', r'U:\baier.ORCA\Attachments', account))
@@ -40,7 +41,8 @@ def editSaveReport(save_to_folder: str):
 
 
 def main():
-    editSaveReport(r'U:\baier.ORCA\Attachments')
+    account = create_account(os.getenv('email_robert'), os.getenv('password_robert'))
+    edit_save_report(r'U:\baier.ORCA\Attachments', account)
 
     attachments = []
     os.chdir(r'U:\baier.ORCA\Attachments')
